# KMS
This Is KMS Library That Created For Hackers In Python Language. Its For Someone Who Need To Create A PowerFul Tool! Because Its Contains Lots Of Things That Hackers Need And Want...

This Is Information Gathering Part Tools:
1. Get (A) Records
2. AS Lookup
3. DNS Lookup
4. Find DNS Servers
5. HTTP Headers
6. IP Location
7. Page Links
8. Ping
9. Reverse IP Lookup
10. Reverse DNS
11. Subnet Calcualtor
12. TCP Port Scanner
13. TraceRoute
14. Whois
15. Zone Transfer

It Contains Two Or Three Types Of Hashing.
And Contains An Inspector That You Can Get Every Some Tags In A Code Or You Can Get Every Information In Site Really Easy!!!
It Contains Two Admin Finder Part And Contains A CMS Finder! For Example You Can Find CMS Js Web Servers And ... With This Command:

`import kms`

`kms.find_cms("web Address")`

Or You Can find Admin Page With These Commands:

`kms.find_admin_php("web Address")`

Or

`kms.find_admin_asp("web Address")`

You Can See Better Explanation And Full Documentation In Wiki...

# Installation

For Install Kms Just Install It From PIP:

`pip install kms`

Really Easy!!
